@@ -31,6 +31,7 @@
 #include "message.h"
 #include "diamenu.h"
 #include "handle.h"
+#include "diarenderer.h"
 
 static void place_handle_by_swapping(NewOrthConn *orth, 
                                      int index, Handle *handle);
@@ -154,9 +155,10 @@ static int get_segment_nr(NewOrthConn *orth, Point *point, real max_dist)
 }
 
 
-void
+ObjectChange*
 neworthconn_move_handle(NewOrthConn *orth, Handle *handle,
-		     Point *to, HandleMoveReason reason)
+			Point *to, ConnectionPoint *cp,
+			HandleMoveReason reason, ModifierKeys modifiers)
 {
   int n;
   int handle_nr;
@@ -204,9 +206,11 @@ neworthconn_move_handle(NewOrthConn *orth, Handle *handle,
     message_error("Internal error in neworthconn_move_handle.\n");
     break;
   }
+
+  return NULL;
 }
 
-void
+ObjectChange*
 neworthconn_move(NewOrthConn *orth, Point *to)
 {
   Point p;
@@ -219,6 +223,8 @@ neworthconn_move(NewOrthConn *orth, Point *to)
   for (i=1;i<orth->numpoints;i++) {
     point_add(&orth->points[i], &p);
   }
+
+  return NULL;
 }
 
 real
@@ -337,7 +343,7 @@ neworthconn_update_boundingbox(NewOrthConn *orth)
 }
 
 void
-neworthconn_simple_draw(NewOrthConn *orth, Renderer *renderer, real width)
+neworthconn_simple_draw(NewOrthConn *orth, DiaRenderer *renderer, real width)
 {
   Point *points;
   
@@ -351,12 +357,12 @@ neworthconn_simple_draw(NewOrthConn *orth, Renderer *renderer, real width)
 
   points = &orth->points[0];
   
-  renderer->ops->set_linewidth(renderer, width);
-  renderer->ops->set_linestyle(renderer, LINESTYLE_SOLID);
-  renderer->ops->set_linejoin(renderer, LINEJOIN_MITER);
-  renderer->ops->set_linecaps(renderer, LINECAPS_BUTT);
+  DIA_RENDERER_GET_CLASS(renderer)->set_linewidth(renderer, width);
+  DIA_RENDERER_GET_CLASS(renderer)->set_linestyle(renderer, LINESTYLE_SOLID);
+  DIA_RENDERER_GET_CLASS(renderer)->set_linejoin(renderer, LINEJOIN_MITER);
+  DIA_RENDERER_GET_CLASS(renderer)->set_linecaps(renderer, LINECAPS_BUTT);
 
-  renderer->ops->draw_polyline(renderer, points, orth->numpoints,
+  DIA_RENDERER_GET_CLASS(renderer)->draw_polyline(renderer, points, orth->numpoints,
 			       &color_black);
 }
 
