@@ -26,11 +26,10 @@
 #include "intl.h"
 #include "object.h"
 #include "element.h"
-#include "render.h"
+#include "diarenderer.h"
 #include "attributes.h"
 #include "text.h"
 #include "properties.h"
-#include "charconv.h"
 
 #include "pixmaps/actor.xpm"
 
@@ -54,11 +53,12 @@ struct _Actor {
 
 static real actor_distance_from(Actor *actor, Point *point);
 static void actor_select(Actor *actor, Point *clicked_point,
-			Renderer *interactive_renderer);
-static void actor_move_handle(Actor *actor, Handle *handle,
-			     Point *to, HandleMoveReason reason, ModifierKeys modifiers);
-static void actor_move(Actor *actor, Point *to);
-static void actor_draw(Actor *actor, Renderer *renderer);
+			DiaRenderer *interactive_renderer);
+static ObjectChange* actor_move_handle(Actor *actor, Handle *handle,
+				       Point *to, ConnectionPoint *cp,
+				       HandleMoveReason reason, ModifierKeys modifiers);
+static ObjectChange* actor_move(Actor *actor, Point *to);
+static void actor_draw(Actor *actor, DiaRenderer *renderer);
 static Object *actor_create(Point *startpoint,
 			   void *user_data,
 			   Handle **handle1,
@@ -119,6 +119,9 @@ static PropDescription actor_props[] = {
 static PropDescription *
 actor_describe_props(Actor *actor)
 {
+  if (actor_props[0].quark == 0) {
+    prop_desc_list_calculate_quarks(actor_props);
+  }
   return actor_props;
 }
 
@@ -157,25 +160,28 @@ actor_distance_from(Actor *actor, Point *point)
 
 static void
 actor_select(Actor *actor, Point *clicked_point,
-	       Renderer *interactive_renderer)
+	       DiaRenderer *interactive_renderer)
 {
   text_set_cursor(actor->text, clicked_point, interactive_renderer);
   text_grab_focus(actor->text, &actor->element.object);
   element_update_handles(&actor->element);
 }
 
-static void
+static ObjectChange*
 actor_move_handle(Actor *actor, Handle *handle,
-		 Point *to, HandleMoveReason reason, ModifierKeys modifiers)
+		  Point *to, ConnectionPoint *cp,
+		  HandleMoveReason reason, ModifierKeys modifiers)
 {
   assert(actor!=NULL);
   assert(handle!=NULL);
   assert(to!=NULL);
 
   assert(handle->id < 8);
+
+  return NULL;
 }
 
-static void
+static ObjectChange*
 actor_move(Actor *actor, Point *to)
 {
   Element *elem = &actor->element;
@@ -185,11 +191,14 @@ actor_move(Actor *actor, Point *to)
   elem->corner.y -= elem->height / 2.0;
 
   actor_update_data(actor);
+
+  return NULL;
 }
 
 static void
-actor_draw(Actor *actor, Renderer *renderer)
+actor_draw(Actor *actor, DiaRenderer *renderer)
 {
+  DiaRendererClass *renderer_ops = DIA_RENDERER_GET_CLASS (renderer);
   Element *elem;
   real x, y, w, h;
   real r, r1;  
@@ -205,9 +214,9 @@ actor_draw(Actor *actor, Renderer *renderer)
   w = elem->width;
   h = elem->height;
   
-  renderer->ops->set_fillstyle(renderer, FILLSTYLE_SOLID);
-  renderer->ops->set_linewidth(renderer, ACTOR_LINEWIDTH);
-  renderer->ops->set_linestyle(renderer, LINESTYLE_SOLID);
+  renderer_ops->set_fillstyle(renderer, FILLSTYLE_SOLID);
+  renderer_ops->set_linewidth(renderer, ACTOR_LINEWIDTH);
+  renderer_ops->set_linestyle(renderer, LINESTYLE_SOLID);
 
   r = ACTOR_HEAD;
   r1 = 2*r;
@@ -217,11 +226,11 @@ actor_draw(Actor *actor, Renderer *renderer)
   cb.y = ch.y + r1 + r;
   
   /* head */
-  renderer->ops->fill_ellipse(renderer, 
+  renderer_ops->fill_ellipse(renderer, 
 			     &ch,
 			     r, r,
 			     &color_white);
-  renderer->ops->draw_ellipse(renderer, 
+  renderer_ops->draw_ellipse(renderer, 
 			     &ch,
 			     r, r,
 			     &color_black);  
@@ -230,25 +239,25 @@ actor_draw(Actor *actor, Renderer *renderer)
   p1.x = ch.x - r1;
   p2.x = ch.x + r1;
   p1.y = p2.y = ch.y + r;
-  renderer->ops->draw_line(renderer, 
+  renderer_ops->draw_line(renderer, 
 			   &p1, &p2,
 			   &color_black);
 
   p1.x = ch.x;
   p1.y = ch.y + r*0.5;
   /* body & legs  */
-  renderer->ops->draw_line(renderer, 
+  renderer_ops->draw_line(renderer, 
 			   &p1, &cb,
 			   &color_black);
 
   p2.x = ch.x - r1;
   p2.y = y + ACTOR_BODY;
-  renderer->ops->draw_line(renderer, 
+  renderer_ops->draw_line(renderer, 
 			   &cb, &p2,
 			   &color_black);
   
   p2.x =  ch.x + r1;
-  renderer->ops->draw_line(renderer, 
+  renderer_ops->draw_line(renderer, 
 			   &cb, &p2,
 			   &color_black);
   
@@ -271,20 +280,28 @@ actor_update_data(Actor *actor)
   /* Update connections: */
   actor->connections[0].pos.x = elem->corner.x;
   actor->connections[0].pos.y = elem->corner.y;
+  actor->connections[0].directions = DIR_NORTH|DIR_WEST;
   actor->connections[1].pos.x = elem->corner.x + elem->width / 2.0;
   actor->connections[1].pos.y = elem->corner.y;
+  actor->connections[1].directions = DIR_NORTH;
   actor->connections[2].pos.x = elem->corner.x + elem->width;
   actor->connections[2].pos.y = elem->corner.y;
+  actor->connections[2].directions = DIR_NORTH|DIR_EAST;
   actor->connections[3].pos.x = elem->corner.x;
   actor->connections[3].pos.y = elem->corner.y + elem->height / 2.0;
+  actor->connections[3].directions = DIR_WEST;
   actor->connections[4].pos.x = elem->corner.x + elem->width;
   actor->connections[4].pos.y = elem->corner.y + elem->height / 2.0;
+  actor->connections[4].directions = DIR_EAST;
   actor->connections[5].pos.x = elem->corner.x;
   actor->connections[5].pos.y = elem->corner.y + elem->height;
+  actor->connections[5].directions = DIR_SOUTH|DIR_WEST;
   actor->connections[6].pos.x = elem->corner.x + elem->width / 2.0;
   actor->connections[6].pos.y = elem->corner.y + elem->height;
+  actor->connections[6].directions = DIR_SOUTH;
   actor->connections[7].pos.x = elem->corner.x + elem->width;
   actor->connections[7].pos.y = elem->corner.y + elem->height;
+  actor->connections[7].directions = DIR_SOUTH|DIR_EAST;
   
   element_update_boundingbox(elem);
 
@@ -315,7 +332,6 @@ actor_create(Point *startpoint,
   Point p;
   DiaFont *font;
   int i;
-  utfchar *utf;
   
   actor = g_malloc0(sizeof(Actor));
   elem = &actor->element;
@@ -327,21 +343,15 @@ actor_create(Point *startpoint,
   elem->width = ACTOR_WIDTH;
   elem->height = ACTOR_HEIGHT;
 
-  /* choose default font name for your locale. see also font_data structure
-     in lib/font.c. */
-  font = font_getfont (_("Helvetica"));
+  font = dia_font_new_from_style (DIA_FONT_SANS, 0.8);
   p = *startpoint;
   p.x += ACTOR_MARGIN_X;
-  p.y += ACTOR_HEIGHT - font_descent(font, 0.8);
+  p.y += ACTOR_HEIGHT - dia_font_descent(_("Actor"),font, 0.8);
 
-#ifdef GTK_DOESNT_TALK_UTF8_WE_DO
-  utf = charconv_local8_to_utf8 (_("Actor"));
-#else
-  utf = g_strdup (_("Actor"));
-#endif
-  actor->text = new_text(utf, 
+  actor->text = new_text(_("Actor"), 
                          font, 0.8, &p, &color_black, ALIGN_CENTER);
-  g_free (utf);
+  dia_font_unref(font);
+  
   text_get_attributes(actor->text,&actor->attrs);
   
   element_init(elem, 8, 8);
