@@ -29,6 +29,7 @@
 #include <string.h>
 #include <math.h>
 #include <glib.h>
+#include <errno.h>
 
 #include "intl.h"
 #include "message.h"
@@ -1153,7 +1154,7 @@ export_cgm(DiagramData *data, const gchar *filename,
     file = fopen(filename, "wb");
 
     if (file == NULL) {
-	message_error(_("Couldn't open: '%s' for writing.\n"), filename);
+	message_error(_("Can't open output file %s: %s\n"), filename, strerror(errno));
 	return;
     }
 
